/**
 * Copyright (C) 2012-2018 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public
 * License version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 */
package org.n52.sos.binding.rest.resources.sensors;


import net.opengis.sosREST.x10.SensorDocument;

import org.n52.sos.binding.rest.requests.RestResponse;
import org.n52.sos.ogc.ows.OwsExceptionReport;
import org.n52.sos.response.ServiceResponse;
import org.n52.sos.util.http.HTTPStatus;

/**
 * @author <a href="mailto:e.h.juerrens@52north.org">Eike Hinderk J&uuml;rrens</a>
 *
 */
public class SensorsPutEncoder extends ASensorsEncoder {
    
    @Override
    public ServiceResponse encodeRestResponse(RestResponse restResponse) throws OwsExceptionReport
    {
        if (restResponse != null && restResponse instanceof SensorsPutResponse) {
            SensorsPutResponse sensorsPutResponse = (SensorsPutResponse) restResponse;
            SensorDocument xb_SensorRestDoc = SensorDocument.Factory.newInstance();
            createRestDefaultRestSensor(sensorsPutResponse, xb_SensorRestDoc);
            
            ServiceResponse response = createServiceResponseFromXBDocument(xb_SensorRestDoc,
                    bindingConstants.getResourceSensors(),
                    HTTPStatus.OK,
                    false,true);
            
            return response;
        }
        throw createResponseNotSupportedException(SensorsPutResponse.class.getName(),restResponse);
    }

}
